@@ -21,15 +21,16 @@ def get_error(error_message):
 class RestApiException(serializers.ValidationError):
     status_code = 400
     default_detail = ""
+    detail = ""
 
 
 class SMSWaitException(RestApiException):
-    default_detail = get_error(conf.SMS_WAIT_TIME)
+    default_detail = detail = get_error(conf.SMS_WAIT_TIME)
 
 
 class UserAlreadyExistException(RestApiException):
-    default_detail = get_error(conf.SMS_USER_ALREADY_EXIST)
+    default_detail = detail = get_error( conf.SMS_WAIT_TIME )
 
 
 class SMSCodeNotFoundException(RestApiException):
-    default_detail = get_error(conf.SMS_CODE_NOT_FOUND)
+    default_detail = detail = get_error( conf.SMS_WAIT_TIME )
